////////////////////////////////////////////////////////////////
// Advertisment Failure Test
//
////////////////////////////////////////////////////////////////


#include "bleprofile.h"
#include "bleapp.h"
#include "blecen.h"
#include "bleappfwu.h"

#include "blecm.h"
#include "gpiodriver.h"

#include "cfa.h"
#include "bleapputils.h"
#include "miadriver.h"

#include "stdio.h"
#include "stdint.h"
#include "string.h"
#include "platform.h"
#include "devicelpm.h"

#include "spar_utils.h"


////////////////////////////////////////////////////////////////
//               Variables Definitions
////////////////////////////////////////////////////////////////

const BLE_PROFILE_CFG adv_fail_test_cfg =
      { /*.fine_timer_interval            =*/
      50, // ms
      /*.default_adv                    =*/NO_DISCOVERABLE, // HIGH_UNDIRECTED_DISCOVERABLE
      /*.button_adv_toggle              =*/0, // pairing button make adv toggle (if 1) or always on (if 0)
      /*.high_undirect_adv_interval     =*/80, // slots
      /*.low_undirect_adv_interval      =*/1024, // slots
      /*.high_undirect_adv_duration     =*/60, // seconds
      /*.low_undirect_adv_duration      =*/120, // seconds
      /*.high_direct_adv_interval       =*/0, // seconds
      /*.low_direct_adv_interval        =*/0, // seconds
      /*.high_direct_adv_duration       =*/0, // seconds
      /*.low_direct_adv_duration        =*/0, // seconds
      /*.local_name                     =*/"MPL Device", // [LOCAL_NAME_LEN_MAX];
      /*.cod                            =*/
        { BIT16_TO_8(APPEARANCE_GENERIC_TAG), 0x00 }, // [COD_LEN];
      /*.ver                            =*/"1.00", // [VERSION_LEN];
      /*.encr_required                  =*/0, //(SECURITY_ENABLED | SECURITY_REQUEST), // data encrypted and device sends security request on every connection
      /*.disc_required                  =*/0, // if 1, disconnection after confirmation
      /*.test_enable                    =*/1, // TEST MODE is enabled when 1
      /*.tx_power_level                 =*/0x04, // dbm
      /*.con_idle_timeout               =*/4, // second  0-> no timeout
      /*.powersave_timeout              =*/0, // second  0-> no timeout
      /*.hdl                            =*/
        { 0x00, 0x00, 0x00, 0x00, 0x00 }, // [HANDLE_NUM_MAX];
      /*.serv                           =*/
        { 0x00, 0x00, 0x00, 0x00, 0x00 },
      /*.cha                            =*/
        { 0x00, 0x00, 0x00, 0x00, 0x00 },
      /*.findme_locator_enable          =*/0, // if 1 Find me locator is enable
      /*.findme_alert_level             =*/0, // alert level of find me
      /*.client_grouptype_enable        =*/0, // if 1 grouptype read can be used
      /*.linkloss_button_enable         =*/0, // if 1 linkloss button is enable
      /*.pathloss_check_interval        =*/0, // second
      /*.alert_interval                 =*/0, // interval of alert
      /*.high_alert_num                 =*/0, // number of alert for each interval
      /*.mild_alert_num                 =*/0, // number of alert for each interval
      /*.status_led_enable              =*/0, // if 1 status LED is enable
      /*.status_led_interval            =*/0, // second
      /*.status_led_con_blink           =*/0, // blink num of connection
      /*.status_led_dir_adv_blink       =*/0, // blink num of dir adv
      /*.status_led_un_adv_blink        =*/0, // blink num of undir adv
      /*.led_on_ms                      =*/0, // led blink on duration in ms
      /*.led_off_ms                     =*/0, // led blink off duration in ms
      /*.buz_on_ms                      =*/0, // buzzer on duration in ms
      /*.button_power_timeout           =*/0, // seconds
      /*.button_client_timeout          =*/0, // seconds
      /*.button_discover_timeout        =*/0, // seconds
      /*.button_filter_timeout          =*/0, // seconds
#ifdef BLE_UART_LOOPBACK_TRACE
    /*.button_uart_timeout            =*/15,   // seconds
#endif
};

// Following structure defines UART configuration
const BLE_PROFILE_PUART_CFG adv_fail_test_puart_cfg =
      {
        /*.baudrate   =*/115200,
        /*.txpin      =*/PUARTDISABLE | GPIO_PIN_UART_TX,
        /*.rxpin      =*/PUARTDISABLE | GPIO_PIN_UART_RX, };

// Following structure defines GPIO configuration used by the application
const BLE_PROFILE_GPIO_CFG adv_fail_test_gpio_cfg =
      {
        /*.gpio_pin =*/
          { -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 // GPIOs are not used
          },
        /*.gpio_flag =*/
          { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 } };

BD_ADDR adv_fail_test_remote_addr =
      { 0, 0, 0, 0, 0, 0 };


extern BLE_CEN_CFG blecen_cen_cfg;
extern BLEAPP_TIMER_CB blecen_usertimerCb;

////////////////////////////////////////////////////////////////
//               Function Prototypes
////////////////////////////////////////////////////////////////

extern void
(*puart_rxCb)(void *);
//! Application Creation as needed by the SDK
static void
adv_fail_test_create(void);

// Application initialization
APPLICATION_INIT()
{
  bleapp_set_cfg(NULL,//(UINT8 *) adv_fail_test_gatt_database,
                 0,//sizeof(adv_fail_test_gatt_database),
                 (void *) &adv_fail_test_cfg,
                 NULL,
                 (void *) &adv_fail_test_gpio_cfg,
                 adv_fail_test_create);

  bleapp_trace_enable = BLE_TRACE_UART_HCI; // BLE_TRACE_UART_NONE;//BLE_TRACE_UART_HCI
}


///////////////////////////////////////////////////////////////////
//! \brief
void
adv_fail_test_create(void)
{
  //blecm_configFlag |= BLECM_DBGUART_LOG;
  blecm_configFlag = 0;

  bleprofile_Init(bleprofile_p_cfg);
  bleprofile_GPIOInit(bleprofile_gpio_p_cfg);

  blecm_setTxPowerInADV(0);
  bleprofile_Discoverable(HIGH_UNDIRECTED_DISCOVERABLE, NULL);
}

